@@ -5,20 +5,7 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Find or build bison, the parser generator
-our $VERSION = '0.18'; # VERSION
-
-
-sub bin_dir
-{
-  my($class) = @_;
-  if($class->install_type('system'))
-  {
-    my $path = $class->config('bison_system_path');
-    return ($path) if $path;
-  }
-
-  return $class->SUPER::bin_dir;
-}
+our $VERSION = '0.19'; # VERSION
 
 
 sub alien_helper
@@ -42,7 +29,7 @@ Alien::bison - Find or build bison, the parser generator
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
